@@ -1,8 +1,15 @@
+
+#include <stdio.h>
+#include <string.h>
+#include <ctype.h>
+#include <time.h>
+
+/* #include "strnlen_compat.h" */
 #include "tldevel.h"
 #include "tlmisc.h"
 #include "esl_stopwatch.h"
 
-#include "version.h"
+/* #include "version.h" */
 
 #include "msa_struct.h"
 #include "msa_alloc.h"
@@ -13,9 +20,6 @@
 
 #include "alphabet.h"
 
-#include <string.h>
-#include <ctype.h>
-
 #define  MSA_IO_IMPORT
 #include "msa_io.h"
 
@@ -134,7 +138,7 @@ int kalign_read_input(char* infile, struct msa** msa, int quiet)
                 free_in_buffer(b);
                 DESTROY_TIMER(timer);
                 *msa = NULL;
-                return OK;
+                return FAIL;  /* Return FAIL instead of OK when no valid format detected */
         }
         m->quiet = quiet;
 
@@ -348,7 +352,7 @@ int read_file_stdin(struct in_buffer** buffer,char* infile)
         char* line = NULL;
         char* tmp = NULL;
         size_t b_len = 0;
-        ssize_t nread;
+        size_t nread;
         int i;
         //char line[BUFFER_LEN];
         int line_len;
@@ -394,7 +398,9 @@ int read_file_stdin(struct in_buffer** buffer,char* infile)
                 }
 
         }
-        fclose(f_ptr);
+        if(f_ptr != stdin){
+                fclose(f_ptr);
+        }
         MFREE(line);
         *buffer = b;
         return OK;
