@@ -274,6 +274,10 @@ int set_sip_nsip(struct msa* msa)
 {
         int i;
         ASSERT(msa!= NULL, "No msa");
+        if(msa->seq_weights){
+                MFREE(msa->seq_weights);
+                msa->seq_weights = NULL;
+        }
         if(msa->plen){
                 for (i = msa->num_profiles;i--;){
                         if(msa->sip[i]){
@@ -354,7 +358,7 @@ int convert_msa_to_internal(struct msa* msa, int type)
                         if(t[(int) seq->seq[j]] == -1){
                                 WARNING_MSG("there should be no character not matching the alphabet");
                                 WARNING_MSG("offending character: >>>%c<<<", seq->seq[j]);
-                                /* exit(0); */
+                                seq->s[j] = 0;
                         }else{
                                 seq->s[j] = t[(int) seq->seq[j]];
                         }
@@ -443,10 +447,17 @@ int kalign_arr_to_msa(char** input_sequences, int* len, int numseq,struct msa**
         msa->numseq = numseq;
         msa->num_profiles = 0;
         msa->L = ALPHA_UNDEFINED;
+        msa->biotype = ALN_BIOTYPE_UNDEF;
         msa->aligned = 0;
+        msa->alnlen = 0;
         msa->plen = NULL;
         msa->sip = NULL;
         msa->nsip = NULL;
+        msa->seq_distances = NULL;
+        msa->col_confidence = NULL;
+        msa->seq_weights = NULL;
+        msa->run_parallel = 0;
+        msa->consistency_table = NULL;
         msa->quiet = 1;
         MMALLOC(msa->sequences, sizeof(struct msa_seq*) * msa->alloc_numseq);
 
@@ -463,6 +474,8 @@ int kalign_arr_to_msa(char** input_sequences, int* len, int numseq,struct msa**
                 seq->seq = NULL;
                 seq->s = NULL;
                 seq->gaps = NULL;
+                seq->confidence = NULL;
+                seq->rank = 0;
                 seq->len = len[i];
                 seq->alloc_len = len[i]+1;
 
