@@ -25,6 +25,7 @@ struct msa_seq{
         char* seq;
         uint8_t* s;
         int* gaps;
+        float* confidence;   /* per-position confidence [0..1], NULL if not computed */
         int rank;
         int len;
         int alloc_len;
@@ -32,6 +33,9 @@ struct msa_seq{
 
 struct msa{
         struct msa_seq** sequences;
+        float* seq_distances;   /* per-sequence mean distance (normalized), set during tree building */
+        float* col_confidence;  /* per-column confidence [0..1], NULL if not computed */
+        float* seq_weights;     /* per-sequence tree-based weight, NULL when not computed */
         int** sip;
         int* nsip;
         int* plen;
@@ -45,6 +49,7 @@ struct msa{
         uint8_t L;
         uint8_t biotype;
         int quiet;
+        void* consistency_table;    /* struct consistency_table*, NULL when disabled */
 };
 
 #undef MSA_STRUCT_IMPORT
