@@ -1,28 +1,8 @@
-/*
-    Kalign - a multiple sequence alignment program
-
-    Copyright 2006, 2019 Timo Lassmann
-
-    This file is part of kalign.
-
-    Kalign is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-*/
-
 #ifndef PARAMETERS_H
 #define PARAMETERS_H
 
+#include <stdint.h>
+
 
 #ifdef PARAMETERS_IMPORT
 #define EXTERN
@@ -61,6 +41,18 @@ struct parameters{
         int nthreads;
         int clean;
         int unalign;
+        int refine;
+        int adaptive_budget;
+        int ensemble;
+        uint64_t ensemble_seed;
+        int min_support;
+        char* save_poar;
+        char* load_poar;
+        int consistency_anchors;
+        float consistency_weight;
+        int realign;
+        float vsm_amax;
+        int mode;  /* 0=default, 1=fast, 2=precise */
         int help_flag;
         int quiet;
 };
